@@ -10,47 +10,14 @@ package Dancer::Plugin::Redis;
 
 # ABSTRACT: easy database connections for Dancer applications
 
-
 use strict;
 use warnings;
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14';    # VERSION
 use Carp;
 use Data::Dumper;
 use Dancer::Plugin;
 use Try::Tiny;
-
-{package RedisWithAuthSupport;
-    use strict;
-    use warnings;
-    use parent 'Redis';
-
-    sub new {
-        my ($class, %param) = @_;
-
-        my $self = $class->SUPER::new(%param);
-        $self->{password} = delete $param{password};
-        $self->__auth;
-
-        return $self;
-    }
-
-    sub __connect {
-        my $self = shift;
-
-        $self->SUPER::__connect;
-        $self->__auth;
-
-        return;
-    }
-
-    sub __auth {
-        my $self = shift;
-
-        $self->auth($self->{password}) if defined $self->{password};
-
-        return;
-    }
-}
+use RedisWithAuthSupport;
 
 my $_settings;
 my $_handles;
@@ -62,15 +29,19 @@ register redis => sub {
 
     $_settings ||= plugin_setting;
 
-    my $conf = $name eq '_default' ? $_settings : $_settings->{connections}->{$name};
-    croak "$name is not defined in your redis conf, please check the doc" unless defined $conf;
+    my $conf
+        = $name eq '_default'
+        ? $_settings
+        : $_settings->{connections}->{$name};
+    croak "$name is not defined in your redis conf, please check the doc"
+        unless defined $conf;
 
     return $_handles->{$name} = RedisWithAuthSupport->new(
-        server => $conf->{server},
-        debug => $conf->{debug},
-        encoding => $conf->{encoding},
+        server    => $conf->{server},
+        debug     => $conf->{debug},
+        encoding  => $conf->{encoding},
         reconnect => $conf->{reconnect} // 60,
-        password => $conf->{password},
+        password  => $conf->{password},
     );
 
 };
@@ -79,7 +50,6 @@ register_plugin;
 
 1;
 
-
 =pod
 
 =head1 NAME
@@ -88,7 +58,7 @@ Dancer::Plugin::Redis - easy database connections for Dancer applications
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -181,5 +151,4 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __END__
